## 0.2.0 (2023-09-11)

### Perf

- Optimized performance impact of middleware

## 0.1.1 (2023-07-27)

### Feat

- Removed dependencies to allow install customized werkzeug like https://pypi.org/project/Werkzeug-mireq/

## 0.1.0 (2023-06-20)

### Feat

- Added starlette usage example
- Added debugger middlewre

### Fix

- Fixed package layout

### Refactor

- Emulate WSGI request, removed check_pin_trust
- Replaced static app with dynamically created
